searchData={"content_type":"text/markdown","items":[{"doc":"Chisel is a library that uses bitmap fonts to sculpt\ntext on any device that can handle pixels.","ref":"Chisel.html","title":"Chisel","type":"module"},{"doc":"Interface for managing fonts","ref":"Chisel.Font.html","title":"Chisel.Font","type":"module"},{"doc":"Loads a font from a file","ref":"Chisel.Font.html#load/2","title":"Chisel.Font.load/2","type":"function"},{"doc":"","ref":"Chisel.Font.html#t:load_opts/0","title":"Chisel.Font.load_opts/0","type":"type"},{"doc":"","ref":"Chisel.Font.html#t:t/0","title":"Chisel.Font.t/0","type":"type"},{"doc":"Defines a glyph for font rendering, including its properties and bitmap data. Useful for managing glyph rendering in graphics applications.","ref":"Chisel.Font.Glyph.html","title":"Chisel.Font.Glyph","type":"module"},{"doc":"- `name`: Identifies the glyph.\n- `codepoint`: Unicode codepoint of the glyph.\n- `dwx`: Horizontal drawing width.\n- `size`: Width and height of the glyph.\n- `offset`: Position offset from the baseline.\n- `data`: Bitmap data of the glyph.","ref":"Chisel.Font.Glyph.html#module-attributes","title":"Attributes - Chisel.Font.Glyph","type":"module"},{"doc":"","ref":"Chisel.Font.Glyph.html#t:codepoint/0","title":"Chisel.Font.Glyph.codepoint/0","type":"type"},{"doc":"","ref":"Chisel.Font.Glyph.html#t:data/0","title":"Chisel.Font.Glyph.data/0","type":"type"},{"doc":"","ref":"Chisel.Font.Glyph.html#t:t/0","title":"Chisel.Font.Glyph.t/0","type":"type"},{"doc":"The renderer is capable of draw the text on any target using for that\na function that receives the x, y coordinates of the pixel to be painted.","ref":"Chisel.Renderer.html","title":"Chisel.Renderer","type":"module"},{"doc":"Draws a character using the codepoint\n\nThe coordinates (`tlx`, `tly`) are for the top left corner.","ref":"Chisel.Renderer.html#draw_char/6","title":"Chisel.Renderer.draw_char/6","type":"function"},{"doc":"Draws an string\n\nThe coordinates (`tlx`, `tly`) are for the top left corner.","ref":"Chisel.Renderer.html#draw_text/6","title":"Chisel.Renderer.draw_text/6","type":"function"},{"doc":"Gets the size of the rendered string using the font and options provided","ref":"Chisel.Renderer.html#get_text_width/3","title":"Chisel.Renderer.get_text_width/3","type":"function"},{"doc":"Draws a character using the codepoint calling a reducer function.\n\nThe coordinates (`tlx`, `tly`) are for the top left corner.","ref":"Chisel.Renderer.html#reduce_draw_char/7","title":"Chisel.Renderer.reduce_draw_char/7","type":"function"},{"doc":"Draws an string calling a reducer function\n\nThe coordinates (`tlx`, `tly`) are for the top left corner.","ref":"Chisel.Renderer.html#reduce_draw_text/7","title":"Chisel.Renderer.reduce_draw_text/7","type":"function"},{"doc":"","ref":"Chisel.Renderer.html#t:acc/0","title":"Chisel.Renderer.acc/0","type":"type"},{"doc":"Use `size_x` and `size_y` options to scale up the font.","ref":"Chisel.Renderer.html#t:draw_options/0","title":"Chisel.Renderer.draw_options/0","type":"type"},{"doc":"The function used to paint the canvas.\n\nChisel will use this function to draw the text.","ref":"Chisel.Renderer.html#t:pixel_fun/0","title":"Chisel.Renderer.pixel_fun/0","type":"type"},{"doc":"The function used to paint the canvas.\n\nChisel will use this function to draw the text.","ref":"Chisel.Renderer.html#t:reduce_pixel_fun/0","title":"Chisel.Renderer.reduce_pixel_fun/0","type":"type"},{"doc":"# Chisel\n![Actions Status](https://img.shields.io/github/actions/workflow/status/luisgabrielroldan/chisel/actions.yml?branch=master)\n[![github.com](https://img.shields.io/github/last-commit/luisgabrielroldan/chisel.svg)](https://github.com/luisgabrielroldan/chisel/commits/master)\n[![Hex version](https://img.shields.io/hexpm/v/chisel.svg \"Hex version\")](https://hex.pm/packages/chisel)\n[![Hex docs](http://img.shields.io/badge/hex.pm-docs-green.svg \"Hex docs\")](https://hexdocs.pm/chisel)\n\nChisel is a library that uses bitmap fonts to sculpt text on any device that can handle pixels.","ref":"readme.html","title":"Chisel","type":"extras"},{"doc":"Add Chisel to your mix.exs deps:\n\n```elixir\n{:chisel, \"~> 0.2.0\"},\n```\n\nRun `mix deps.get` to download the new dependency.","ref":"readme.html#setup","title":"Setup - Chisel","type":"extras"},{"doc":"1. Take a function to draw pixels...\n\n```elixir\n  put_pixel = fn x, y ->\n    YourDisplay.draw_pixel(x, y, ...)\n  end\n```\n\n2. Pick a BDF font (Look for one on the Internet or take one from the fixtures folder on this project)\n\n```elixir\n  {:ok, font} = Chisel.Font.load(\"foo/bar/font.bdf\")\n```\n\n3. Use Chisel to sculpt the text using the provided function and font\n\n```elixir\n  Chisel.Renderer.draw_text(\"Hello World!\", x, y, font, put_pixel)\n```\n\n4. Enjoy!\n\n![Demo](images/demo-inky.jpg)\n\n(Thanks to [lawik](https://github.com/lawik) for the picture)","ref":"readme.html#usage","title":"Usage - Chisel","type":"extras"},{"doc":"Chisel is a general purpose library that can be used to render text on any target based on pixels (LCD, Led matrixs, image files, ...).","ref":"readme.html#general-purpose","title":"General purpose - Chisel","type":"extras"},{"doc":"```elixir\n  img = :egd.create(200, 50)\n  color = :egd.color({0, 0, 0})\n\n  put_pixel = fn x, y ->\n    :egd.line(img, {x, y}, {x, y}, color)\n  end\n\n  {:ok, font} = Chisel.Font.load(\"font.bdf\")\n\n  Chisel.Renderer.draw_text(\"Hello World!\", 0, 0, font, put_pixel)\n\n  :egd.save(:egd.render(img, :png), \"test.png\")\n```","ref":"readme.html#render-on-an-image-with-egd","title":"Render on an image with `:egd` - Chisel","type":"extras"},{"doc":"```elixir\n  put_pixel = fn x, y, pixels ->\n    [{x, y} | pixels]\n  end\n\n  {:ok, font} = Chisel.Font.load(\"c64.bdf\")\n\n  {pixels, _, _} = Chisel.Renderer.reduce_draw_text(\"Hello World!\", 0, 0, font, [], put_pixel)\n\n  for y <- 0..10 do\n    for x <- 0..100 do\n      if Enum.member?(pixels, {x, y}) do\n        \"%\"\n      else\n        \" \"\n      end\n    end\n    |> IO.puts()\n  end\n```\n\nResult:\n```\n                                                                                                     \n                                                                                                     \n %%  %%                                          %%   %%                                   %%        \n %%  %%           %%%     %%%                    %%   %%                  %%%        %%    %%        \n %%  %%   %%%%     %%      %%     %%%%           %%   %%  %%%%   %%%%%     %%        %%    %%        \n %%%%%%  %%  %%    %%      %%    %%  %%          %% % %% %%  %%  %%  %%    %%     %%%%%    %%        \n %%  %%  %%%%%%    %%      %%    %%  %%          %%%%%%% %%  %%  %%        %%    %%  %%              \n %%  %%  %%        %%      %%    %%  %%          %%% %%% %%  %%  %%        %%    %%  %%              \n %%  %%   %%%%    %%%%    %%%%    %%%%           %%   %%  %%%%   %%       %%%%    %%%%%    %%        \n                                                                                                     \n                                                                                                     \n```","ref":"readme.html#render-ascii-art","title":"Render ASCII art - Chisel","type":"extras"},{"doc":"![OLED Demo](images/demo-oled.jpg)\n\nUsing the right font it is even possible to render unicode strings.\n\nMany good BDF fonts are available [here](https://github.com/olikraus/u8g2/tree/master/tools/font/bdf) on the [U8g2](https://github.com/olikraus/u8g2) library repo.\n\nCheck fonts licenses [here](https://github.com/olikraus/u8g2/wiki/fntgrp).","ref":"readme.html#samples-using-oled-https-github-com-pappersverk-oled","title":"Samples using [OLED](https://github.com/pappersverk/oled) - Chisel","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}